@@ -4,12 +4,15 @@
 ## Metadata 'title': 'Paired PSCBS'
 ## Metadata 'author': 'Henrik Bengtsson'
 ## Metadata 'keywords': 'copy numbers, allele specific, parent specific, genomic aberrations'
+## Metadata 'engine': 'R.rsp::rsp'
 ###########################################################################
 
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 t0 <- Sys.time()
 library("PSCBS");
 library("R.devices");
+evalCapture <- R.utils::evalCapture;
+PSCBS <- R.oo::Package("PSCBS");
+R.rsp <- R.oo::Package("R.rsp");
 fixLocations <- function(fit, ...) {
   for (key in grep("(End|Start)$", colnames(fit$output))) {
     fit$output[[key]] <- as.integer(fit$output[[key]]);
@@ -23,7 +26,7 @@ options(digits=3);
 options(str=strOptions(strict.width="cut"));
 R.rsp$version
 R.rsp$author
-format(as.Date(getDate(Package("PSCBS"))), format="%B %d, %Y")
+format(as.Date(PSCBS$date), format="%B %d, %Y")
 fullname <- "PairedPSCBS,exData,chr01";
 evalCapture({
 data <- PSCBS::exampleData("paired.chr01")
@@ -79,4 +82,3 @@ toPNG(fullname, tags=c("pruned", "tracks"), aspectRatio=0.6, {
 toLatex(sessionInfo())
 dt <- round(Sys.time()-t0, digits=2)
 attr(dt, "units")
-
